==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/weapon/MagicBroom.java <==
package cc.thonly.reverie_dreams.item.weapon;

import cc.thonly.reverie_dreams.data.ModTags;
import cc.thonly.reverie_dreams.entity.ModEntities;
import cc.thonly.reverie_dreams.entity.misc.MagicBroomEntity;
import cc.thonly.reverie_dreams.item.base.SwordItem;
import cc.thonly.reverie_dreams.recipe.ItemStackWrapper;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_9886;

public class MagicBroom extends SwordItem {
    public static final class_9886 MAGIC_BROOM = new class_9886(ModTags.BlockTypeTag.EMPTY, 750, 7.5f, 4.0f, 10, ModTags.ItemTypeTag.POWER_BLOCK);

    public MagicBroom(float attackDamage, float attackSpeed, class_1792.class_1793 settings) {
        super(MAGIC_BROOM, attackDamage, attackSpeed, settings);
    }

    @Override
    public class_1269 method_7884(class_1838 context) {
        class_1937 world = context.method_8045();
        class_1799 itemStack = context.method_8041();
        class_1657 player = context.method_8036();
        class_2338 blockPos = context.method_8037();
        class_1268 hand = context.method_20287();
        if (!world.method_8608() && player != null) {
            MagicBroomEntity entity = new MagicBroomEntity(ModEntities.BROOM_ENTITY_TYPE, world, blockPos.method_10263(), blockPos.method_10264() + 1, blockPos.method_10260(), ItemStackWrapper.of(itemStack.method_7972()), player.method_5667().toString().intern());
            world.method_8649(entity);
            itemStack.method_57008(1, player);
            player.method_6104(hand);
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }

}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/weapon/MagicBroom.java <==
package cc.thonly.reverie_dreams.item.weapon;

import cc.thonly.reverie_dreams.registry.tag.RDBlockTags;
import cc.thonly.reverie_dreams.registry.tag.RDItemTags;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_9886;
import cc.thonly.reverie_dreams.registry.content.entity.RDEntityTypes;
import cc.thonly.reverie_dreams.entity.misc.MagicBroomEntity;
import cc.thonly.reverie_dreams.item.base.SwordItem;
import cc.thonly.reverie_dreams.recipe.ItemStackWrapper;

public class MagicBroom extends SwordItem {
    public static final class_9886 MAGIC_BROOM = new class_9886(RDBlockTags.EMPTY, 750, 7.5f, 4.0f, 10, RDItemTags.POWER_BLOCK);

    public MagicBroom(float attackDamage, float attackSpeed, class_1792.class_1793 settings) {
        super(MAGIC_BROOM, attackDamage, attackSpeed, settings);
    }

    @Override
    public class_1269 method_7884(class_1838 context) {
        class_1937 world = context.method_8045();
        class_1799 itemStack = context.method_8041();
        class_1657 player = context.method_8036();
        class_2338 blockPos = context.method_8037();
        class_1268 hand = context.method_20287();
        if (!world.method_8608() && player != null) {
            MagicBroomEntity entity = new MagicBroomEntity(RDEntityTypes.BROOM_ENTITY_TYPE, world, blockPos.method_10263(), blockPos.method_10264() + 1, blockPos.method_10260(), ItemStackWrapper.of(itemStack.method_7972()), player.method_5667());
            world.method_8649(entity);
            itemStack.method_57008(1, player);
            player.method_6104(hand);
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }

}
